import React, { useState } from 'react';
import Grid2 from '@mui/material/Grid2';
import ShipmentPanel from '../components/ShipmentPanel';
import ShipmentDetails from '../components/ShipmentDetails';
import ShipmentForm from '../components/ShipmentForm';
import { Shipment_Input } from '../../openapi';

type ShipmentViewProps = {};

const ShipmentView: React.FC<ShipmentViewProps> = () => {
    const [isCreatingShipment, setIsCreatingShipment] = useState(false);
    const [selectedShipment, setSelectedShipment] = useState<Shipment_Input | null>(null);

    const handleSelectShipment = (shipment: Shipment_Input | null) => {
        setSelectedShipment(shipment);
        setIsCreatingShipment(false);
    };

    const handleCancelShipmentForm = () => {
        setIsCreatingShipment(false);
    };

    const renderShipmentContent = () => {
        if (isCreatingShipment) {
            return <ShipmentForm sx={{ flexGrow: 1 }} onCancel={handleCancelShipmentForm} />;
        }
        if (selectedShipment) {
            return <ShipmentDetails isCreatingShipment={isCreatingShipment} sx={{ flexGrow: 1 }} selectedShipment={selectedShipment} />;
        }
        return <div>No shipment details available.</div>;
    };

    return (
        <Grid2 container spacing={2} sx={{ height: '100vh' }}>
            <Grid2
                item
                xs={12}
                md={4}
                sx={{
                    display: 'flex',
                    flexDirection: 'column',
                    flexGrow: 0,
                }}
            >
                <ShipmentPanel
                    selectedPage="Shipments"
                    setCreatingShipment={setIsCreatingShipment}
                    selectShipment={handleSelectShipment}
                />
            </Grid2>
            <Grid2
                item
                xs={12}
                md={8}
                sx={{
                    display: 'flex',
                    flexDirection: 'column',
                    flexGrow: 1,
                }}
            >
                {renderShipmentContent()}
            </Grid2>
        </Grid2>
    );
};

export default ShipmentView;